%bcond_with pacemaker
%global with_pacemaker 1

%define major	9
%define minor	15
%define sub	1
%define pre	0
%define drbd_api_ver	88

Name:		drbd-utils
Version:	%{major}.%{minor}.%{sub}
Release:	%mkrel 4
Summary:	Utilities to manage DRBD devices
License:	GPLv2+
Group:		System/Kernel and hardware
URL:		http://www.drbd.org/
Source:		https://www.linbit.com/downloads/drbd/utils/drbd-utils-%{version}.tar.gz
# Install bash completion file on Mandriva
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	xsltproc
BuildRequires:	docbook-style-xsl
BuildRequires:	pkgconfig(udev)
Requires(post):	rpm-helper
Requires(preun):	rpm-helper
Requires(post):	initscripts
Requires:	drbd-api = %{drbd_api_ver}
Requires:	bash-completion
ExclusiveArch: %{ix86} x86_64 aarch64

%if %{with pacemaker}
%package pacemaker
Summary:       Script to help integration with heartbeat
Group:         System/Kernel and hardware
Requires:      pacemaker
Requires:      %{name} = %{version}
%endif

%description
DRBD is a block device which is designed to build High Availability clusters.
This is done by mirroring a whole block device via (maybe dedicated) network.
You could see it as a network RAID 1. This package contains the tools to
manage DRBD devices.

%if %{with pacemaker}
%description pacemaker
Installs the datadisk script, designed to ease integration with pacemaker.
%endif

%prep
%setup -q
%autopatch -p1

# non-arch executable in datadir, fix conf file
sed -i 's,%{_libdir}/drbd/outdate-peer\.sh,%{_datadir}/drbd/outdate-peer.sh,g' scripts/drbd.conf

%build
%configure \
	--with-udev \
	--with-distro=generic \
	--with-initscripttype=systemd \
	--with-systemdunitdir=%{_unitdir} \
	--with-bashcompletion \
	--without-heartbeat \
%if %{with pacemaker}
	--with-pacemaker\
%else
	--without-pacemaker\
%endif
	--with-prebuiltman \
	--without-xen
%make_build

%install
%make_install

install -d %{buildroot}%{_var}/lib/drbd
install -d %{buildroot}{%{_bindir},%{_sbindir}}

mkdir -p %{buildroot}%{_datadir}/drbd
mkdir -p %{buildroot}%{_sysconfdir}/multipath/conf.d/

%post
%_post_service drbd

%preun
%_preun_service drbd

%files
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/drbd.conf
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/drbd.d/global_common.conf
%dir %{_var}/lib/drbd
%{_sysconfdir}/bash_completion.d/drbdadm
%{_sysconfdir}/multipath/conf.d/drbd.conf
%{_unitdir}/drbd.service
%{_tmpfilesdir}/drbd.conf
%{_udevrulesdir}/65-drbd.rules
%{_sbindir}/drbdadm
%{_sbindir}/drbdmeta
%{_sbindir}/drbdsetup
%{_sbindir}/drbdmon
%dir %{_datadir}/drbd
/lib/drbd/drbd
/lib/drbd/drbdadm-*
/lib/drbd/drbdsetup-*
%{_prefix}/lib/drbd/*.sh

%{_mandir}/man5/*
%{_mandir}/man8/*
%{_mandir}/ja/man5/*
%{_mandir}/ja/man8/*

%if %{with pacemaker}
%files pacemaker
%{_prefix}/lib/ocf/resource.d/linbit/*
%{_mandir}/man7/*

%endif


%changelog
* Thu Mar 24 2022 umeabot <umeabot> 9.15.1-4.mga9
+ Revision: 1825172
- Mageia 9 Mass Rebuild

* Tue Mar 08 2022 mrambo3501 <mrambo3501> 9.15.1-3.mga9
+ Revision: 1789858
- fix files list

* Thu Jan 07 2021 luigiwalser <luigiwalser> 9.15.1-2.mga8
+ Revision: 1669594
- drbd-api is not provided on armv7hl

* Thu Dec 31 2020 tmb <tmb> 9.15.1-1.mga8
+ Revision: 1666674
- update to 9.15.1

* Wed Aug 19 2020 martinw <martinw> 9.13.1-1.mga8
+ Revision: 1615959
- new version 9.13.1

* Thu Feb 13 2020 umeabot <umeabot> 8.9.1-0.7.mga8
+ Revision: 1512135
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Sep 24 2018 daviddavid <daviddavid> 8.9.1-0.6.mga7
+ Revision: 1303089
- add patch to fix build with new glibc
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Tue Feb 09 2016 umeabot <umeabot> 8.9.1-0.5.mga6
+ Revision: 952293
- Mageia 6 Mass Rebuild

* Mon Feb 16 2015 luigiwalser <luigiwalser> 8.9.1-0.4.mga5
+ Revision: 814991
- BR docbook-style-xsl for manpages/docbook.xsl

* Wed Oct 15 2014 umeabot <umeabot> 8.9.1-0.3.mga5
+ Revision: 739557
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 8.9.1-0.2.mga5
+ Revision: 678859
- Mageia 5 Mass Rebuild

* Sun Sep 07 2014 tmb <tmb> 8.9.1-0.1.mga5
+ Revision: 673378
- BR: xsltproc
- update to 8.9.1
- update filelists

* Tue Oct 22 2013 umeabot <umeabot> 8.4.4-2.mga4
+ Revision: 544842
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 tmb <tmb> 8.4.4-1.mga4
+ Revision: 500398
- update to 8.4.4

* Sun Jan 20 2013 dlucio <dlucio> 8.4.2-1.mga4
+ Revision: 390285
- Correct mkrel
- 8.4.2
- P0 rediffed
- We drop heartbeat now we use pacemaker
- Lets use bash-completion

* Wed Jan 16 2013 fwang <fwang> 8.3.11-4.mga3
+ Revision: 388491
- correct udev rules dir

* Fri Jan 11 2013 umeabot <umeabot> 8.3.11-3.mga3
+ Revision: 349106
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Apr 20 2012 boklm <boklm> 8.3.11-2.mga2
+ Revision: 232185
- disable heartbeat

* Tue Apr 03 2012 ennael <ennael> 8.3.11-1.mga2
+ Revision: 228186
- sync userspace tools with kernel module

* Thu Sep 08 2011 tv <tv> 8.3.10-1.mga2
+ Revision: 141560
- new release

* Thu May 26 2011 pterjan <pterjan> 8.3.9-3.mga1
+ Revision: 100510
- Fix configure parameter
+ boklm <boklm>
- rebuild with heartbeat as it is now available

* Thu May 26 2011 boklm <boklm> 8.3.9-2.mga1
+ Revision: 100488
- use make macro
- disable heartbeat as it is not available

* Mon May 16 2011 boklm <boklm> 8.3.9-1.mga1
+ Revision: 99259
- version 8.3.9
- imported package drbd-utils


* Tue May 03 2011 Oden Eriksson <oeriksson@mandriva.com> 8.3.7-4mdv2011.0
+ Revision: 663878
- mass rebuild

* Mon Apr 04 2011 Leonardo Coelho <leonardoc@mandriva.com> 8.3.7-3
+ Revision: 650372
-release bump
- updated version 8.3.7

* Thu Dec 02 2010 Oden Eriksson <oeriksson@mandriva.com> 8.3.5-2mdv2011.0
+ Revision: 604829
- rebuild

* Sat Nov 07 2009 Frederik Himpe <fhimpe@mandriva.org> 8.3.5-1mdv2010.1
+ Revision: 462678
- Update to new version 8.3.5
- Fix installation of bash_completion on Mandriva

* Fri Jul 03 2009 Thomas Backlund <tmb@mandriva.org> 8.3.2-1mdv2010.0
+ Revision: 391939
- update to 8.3.2
- rediff patch0
- update filelists

* Fri Apr 03 2009 Thomas Backlund <tmb@mandriva.org> 8.3.1-1mdv2009.1
+ Revision: 363734
- update to 8.3.1

* Sat Feb 14 2009 Thomas Backlund <tmb@mandriva.org> 8.3.0-1mdv2009.1
+ Revision: 340323
- update drbd-utils to 8.3.0

* Wed Jul 23 2008 Thomas Backlund <tmb@mandriva.org> 8.2.6-1mdv2009.0
+ Revision: 241287
- update to 8.2.6

* Tue Jun 17 2008 Thierry Vignaud <tv@mandriva.org> 8.0.11-3mdv2009.0
+ Revision: 220706
- rebuild

* Wed Feb 13 2008 Marcelo Ricardo Leitner <mrl@mandriva.com> 8.0.11-2mdv2008.1
+ Revision: 167159
- New upstream: 8.0.11
- Removed es and pt-BR i18n from specfile.
- compare.pl is not shipped by upstream anymore.

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Adam Williamson <awilliamson@mandriva.org>
    - new version 8.0.8

* Thu Sep 06 2007 Adam Williamson <awilliamson@mandriva.org> 8.0.6-1mdv2008.0
+ Revision: 80699
- rediff patch
- use Fedora license policy
- new release 8.0.6

* Sun Jul 01 2007 Adam Williamson <awilliamson@mandriva.org> 8.0.3-1mdv2008.0
+ Revision: 46612
- new release 8.0.3, rebuild for 2008


* Mon Sep 11 2006 Andreas Hasenack <andreas@mandriva.com>
+ 2006-09-11 19:52:16 (60907)
- ok, so _lib is not equal to lib
- be more careful removing directories

* Mon Sep 11 2006 Andreas Hasenack <andreas@mandriva.com>
+ 2006-09-11 19:38:45 (60902)
- bump release

* Mon Sep 11 2006 Andreas Hasenack <andreas@mandriva.com>
+ 2006-09-11 19:37:09 (60901)
- move arch-independant file to proper place, adjust conf file. This
  fixes x86_64 build

* Wed Aug 30 2006 Andreas Hasenack <andreas@mandriva.com>
+ 2006-08-30 21:35:07 (58890)
- add pre version to release

* Wed Aug 30 2006 Andreas Hasenack <andreas@mandriva.com>
+ 2006-08-30 20:54:52 (58882)
- removed changelog section, this package is in svn

* Wed Aug 30 2006 Marcelo Ricardo Leitner <mrl@mandriva.com>
+ 2006-08-30 20:39:10 (58879)
- Fixed usrsbin patch version.

* Wed Aug 30 2006 Marcelo Ricardo Leitner <mrl@mandriva.com>
+ 2006-08-30 20:38:16 (58878)
- New upstream: 8.0pre4
- Added P0 due to new upstream.
- Fixed /var/lib/lib/drbd issue.
- Merged fixes from 2006.

* Wed Aug 30 2006 Marcelo Ricardo Leitner <mrl@mandriva.com>
+ 2006-08-30 20:34:41 (58877)
- Synced with cooker with parts from 2006 (the package was updated outside svn):
  * Fri Jul 07 2006 Vincent Danen <vdanen@mandriva.com> 0.7.19-2.1.20060mdk
  - build for updates
  * Mon Jul 03 2006 Nicolas Lécureuil <neoclust@mandriva.org> 0.7.19-3mdk
  - Fix Requires
  * Mon Jun 19 2006 Marcelo Ricardo Leitner <mrl@mandriva.com> 0.7.19-2mdk
  - Added Requires to drbd-api = 78
  * Thu Jun 08 2006 Marcelo Ricardo Leitner <mrl@mandriva.com> 0.7.19-1mdk
  - New upstream: 0.7.19
  - Fixed drbd{adm,setup} paths through patch usrsbin.
  * Mon Dec 26 2005 Nicolas Lécureuil <neoclust@mandriva.org> 0.7.15-1mdk
  - New release 0.7.15
  - Drop patch 0 : Merged upstream
  * Thu Nov 03 2005 Nicolas Lécureuil <neoclust@mandriva.org> 0.7.14-1mdk
  - 0.7.14
  * Wed Aug 10 2005 Nicolas Lécureuil <neoclust@mandriva.org> 0.7.10-4mdk
  - fix BuildRequires
  * Sat Jul 30 2005 Nicolas Lécureuil <neoclust@mandriva.org> 0.7.10-3mdk
  - Add Bison as BuildRequires

* Mon May 29 2006 Andreas Hasenack <andreas@mandriva.com>
+ 2006-05-29 14:36:37 (31646)
- renamed mdv to packages because mdv is too generic and it's hosting only packages anyway

* Fri Jul 08 2005 Flavio Bruno Leitner <fbl@mandriva.com>
+ 2005-07-08 11:01:45 (345)
- fixed URL

* Mon Jul 04 2005 Flavio Bruno Leitner <fbl@mandriva.com>
+ 2005-07-04 14:10:58 (287)
- fixed rpmlint errors

* Thu Jun 23 2005 Flavio Bruno Leitner <fbl@mandriva.com>
+ 2005-06-23 16:31:44 (239)
- added drbd sources and spec file.

* Thu Jun 23 2005 Flavio Bruno Leitner <fbl@mandriva.com>
+ 2005-06-23 13:42:50 (238)
- Created package structure for drbd-utils.

